package com.ruoyi.brewery.mapper;

import java.util.List;
import com.ruoyi.brewery.domain.WyBreweryRoleMenu;

/**
 * 品牌方角色和菜单关联Mapper接口
 * 
 * @author ruoyi
 * @date 2024-12-22
 */
public interface WyBreweryRoleMenuMapper 
{
    /**
     * 查询品牌方角色和菜单关联
     * 
     * @param roleId 品牌方角色和菜单关联主键
     * @return 品牌方角色和菜单关联
     */
    public WyBreweryRoleMenu selectWyBreweryRoleMenuByRoleId(Long roleId);

    /**
     * 查询品牌方角色和菜单关联列表
     * 
     * @param wyBreweryRoleMenu 品牌方角色和菜单关联
     * @return 品牌方角色和菜单关联集合
     */
    public List<WyBreweryRoleMenu> selectWyBreweryRoleMenuList(WyBreweryRoleMenu wyBreweryRoleMenu);

    /**
     * 新增品牌方角色和菜单关联
     * 
     * @param wyBreweryRoleMenu 品牌方角色和菜单关联
     * @return 结果
     */
    public int insertWyBreweryRoleMenu(WyBreweryRoleMenu wyBreweryRoleMenu);

    /**
     * 修改品牌方角色和菜单关联
     * 
     * @param wyBreweryRoleMenu 品牌方角色和菜单关联
     * @return 结果
     */
    public int updateWyBreweryRoleMenu(WyBreweryRoleMenu wyBreweryRoleMenu);

    /**
     * 删除品牌方角色和菜单关联
     * 
     * @param roleId 品牌方角色和菜单关联主键
     * @return 结果
     */
    public int deleteWyBreweryRoleMenuByRoleId(Long roleId);

    /**
     * 批量删除品牌方角色和菜单关联
     * 
     * @param roleIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteWyBreweryRoleMenuByRoleIds(Long[] roleIds);
}
